@@ -8,7 +8,7 @@ class TestTaxonomyMethods(unittest.TestCase):
     def test_taxonomy(self):
         self.taxonomy = Taxonomy()
         n = self.taxonomy.tax.nodes(data=True)['2']
-        self.assertEqual(n['name'], 'Bacteria')
+        self.assertEqual(n['name_'], 'Bacteria')
         # self.assertEqual('Bacteria', 'Bacteria')
 
 
